@@ -14,7 +14,7 @@ log = logging.getLogger('tgext.debugbar')
 
 class DebugBar():
 
-    css_link = u'<link rel="stylesheet" type="text/css" href="%s"></link>'
+    css_link = u'<link rel="stylesheet" type="text/css" href="%s" />'
     css_path = '/_debugbar/statics/style.css'
     template = 'tgext.debugbar.templates.debugbar'
 
@@ -52,9 +52,10 @@ class DebugBar():
 
     def render_bars(self, response):
         page = response.get('response')
-        if (not page or 'text/html' not in response['content_type']
-                or not isinstance(page, unicode) or request.headers.get(
-                    'X-Requested-With', None) == 'XMLHttpRequest'):
+        if (not page or not isinstance(page, unicode)
+                or 'text/html' not in response['content_type']
+                or request.headers.get(
+                    'X-Requested-With') == 'XMLHttpRequest'):
             return
         pos_head = page.find('</head>')
         if pos_head > 0:
