@@ -20,7 +20,6 @@ try:
 except ImportError:
     pstats = None
 
-
 def on_before_render(*args, **kw):
     request.tgdb_render_start_time = time.time()
 
@@ -29,7 +28,15 @@ def on_after_render(response, *args, **kw):
     now = time.time()
     request.tgdb_render_info = response
     request.tgdb_render_time = (now - request.tgdb_render_start_time) * 1000
-    request.tgdb_total_time = (now - request.tgdb_call_start_time) * 1000
+
+    try:
+        request.tgdb_total_time = (now - request.tgdb_call_start_time) * 1000
+    except:
+        request.tgdb_total_time = -1
+        request.tgdb_call_start_time = -1
+        request.tgdb_call_time = -1
+        request.tgdb_profiling_function_calls = []
+        request.tgdb_profiling_stats = []
 
 
 def profile_wrapper(decoration, controller):
@@ -116,9 +123,9 @@ class TimingDebugSection(DebugSection):
         finally:
             delattr(request, 'tgdb_render_info')
             delattr(request, 'tgdb_call_start_time')
+            delattr(request, 'tgdb_call_time')
             delattr(request, 'tgdb_render_start_time')
             delattr(request, 'tgdb_total_time')
             delattr(request, 'tgdb_render_time')
-            delattr(request, 'tgdb_call_time')
             delattr(request, 'tgdb_profiling_stats')
             delattr(request, 'tgdb_profiling_function_calls')
